;; F.R. Gobet & G. Jones, October 1998.
;; ------------------------------------
;; The load file for functions which process a
;; word/phoneme lexicon file. Further comments can be
;; found in lexicon.lisp.
;;
;; This file contains four variables which require setting:
;; *primary-access-orthographic* - Whether the majority of your accesses
;;                                 will be to find the phonemic representation
;;                                 of words (if so set this to t) or the
;;                                 majority of access will be to find the 
;;                                 orthographic representation of phonemes
;;                                 (if so set this to t).
;; *lexicon-pathname*            - The pathname for where the lexicon.lisp
;;                                 file resides.
;; *raw-lexicon-filepath*        - The pathname for the lexicon text file
;;                                 as obtained from 
;;                                 http://www.speech.cs.cmu.edu/cgi-bin/cmudict.
;; *recoded-lexicon-filepath*    - The pathname for where you want the
;;                                 recoded lexicon file to be placed.
;;
;; CHANGE RECORD
;; Ini  Date      Change summary & functions added, deleted, or altered.
;; ---  --------  ------------------------------------------------------
;; GJ   27/02/99  Added *hard-drive* variable, which is then used for
;;                setting pathnames.
;; ---  --------  ------------------------------------------------------
;; GJ   03/03/99  Changed to load ALL lexicon related files in one go. Also
;;                the logical-dir and general-functions stuff gets
;;                loaded from here now.
;; ---  --------  ------------------------------------------------------
;; GJ   03/03/99  Deleted *lexicon-pathname* and added a setting of
;;                the *project-directory* instead.
;;                ------------------------------------------------------

;; Variable 1 - Set hard drive name.
(defvar *hard-drive* "HD")

;; Variable 2 - Set project directory where all codes and databases reside.
(defvar *project-directory* (concatenate 'string
                                         *hard-drive*
                                         ":Syntax project:Lexicon:"))
;; Variable 3 - Set filepath of raw lexicon.
(defvar *raw-lexicon-filepath* (concatenate 'string
                                              *hard-drive*
                                              ":Syntax project:Lexicon:Raw lexicon"))
;; Variable 4 - Set filepath for where you want the recoded lexicon to go.
(defvar *recoded-lexicon-filepath* (concatenate 'string
                                                  *hard-drive*
                                                  ":Syntax project:Lexicon:Recoded lexicon"))

;; Variable 5 - Set the main access type for the lexicon.
(defvar *primary-access-orthographic* t)

(cond
  ((member "4" (mapcar #'string (coerce (lisp-implementation-version) 'list))
           :test #'equal)
    (load (concatenate 'string  *hard-drive*
                       ":logical-dir-compatibility.pfsl")))
  (t
    (load (concatenate 'string  *hard-drive*
                       ":logical-dir-compatibility.fasl"))))
(def-logical-directory "home;" *project-directory*)

(Load (concatenate 'string *project-directory* "general-functions.lisp"))
(Load (concatenate 'string *project-directory* "lexicon.lisp"))
(Load (concatenate 'string *project-directory* "random-lexicon.lisp"))
(Load (concatenate 'string *project-directory* "filter.lisp"))
(Load (concatenate 'string *project-directory* "convert-utterances.lisp"))
(Load (concatenate 'string *project-directory* "psycho-db.lisp"))
(Load (concatenate 'string *project-directory* "phoneme-frequencies.lisp"))